@@ -1,90 +1,88 @@
 #' Sample from an inhomogeneous Poisson process
 #'
 #' This function provides point samples from one- and two-dimensional inhomogeneous Poisson processes. The
-#' log intensity has to be provided via its values at the nodes of an \code{inla.mesh.1d} or
-#' \code{inla.mesh} object. In between mesh nodes the log intensity is assumed to be linear.
+#' log intensity has to be provided via its values at the nodes of an `inla.mesh.1d` or
+#' `inla.mesh` object. In between mesh nodes the log intensity is assumed to be linear.
 #'
-#' For 2D processes on a sphere the \code{R} parameter can be used to adjust to sphere's radius implied by
-#' the mesh. If the intensity is very high the standard \code{strategy} "spherical" can cause memory issues.
+#' For 2D processes on a sphere the `R` parameter can be used to adjust to sphere's radius implied by
+#' the mesh. If the intensity is very high the standard `strategy` "spherical" can cause memory issues.
 #' Using the "sliced-spherical" strategy can help in this case.
 #'
 #' @aliases sample.lgcp
 #' @export
 #'
-#' @param mesh An \link[INLA]{inla.mesh} object
+#' @param mesh An [inla.mesh][INLA::inla.mesh] object
 #' @param loglambda vector or matrix; A vector of log intensities at the mesh vertices
 #'   (for higher order basis functions, e.g.
-#'   for \code{inla.mesh.1d} meshes, \code{loglambda} should be given as \code{mesh$m} basis
-#'   function weights rather than the values at the \code{mesh$n} vertices)
+#'   for `inla.mesh.1d` meshes, `loglambda` should be given as `mesh$m` basis
+#'   function weights rather than the values at the `mesh$n` vertices)
 #'   A single scalar is expanded to a vector of the appropriate length.
 #'   If a matrix is supplied, one process sample for each column is produced.
-#' @param strategy Only relevant for 2D meshes. One of \code{'triangulated'}, \code{'rectangle'},
-#'   \code{'sliced-spherical'}, \code{'spherical'}. The \code{'rectangle'} method is only valid for
+#' @param strategy Only relevant for 2D meshes. One of `'triangulated'`, `'rectangle'`,
+#'   `'sliced-spherical'`, `'spherical'`. The `'rectangle'` method is only valid for
 #'   CRS-less flat 2D meshes.
-#'   If \code{NULL} or \code{'auto'}, the the likely fastest method is chosen;
-#'   \code{'rectangle'} for flat 2D meshes with no CRS,
-#'   \code{'sliced-spherical'} for CRS \code{'longlat'} meshes, and
-#'   \code{'triangulated'} for all other meshes.
+#'   If `NULL` or `'auto'`, the the likely fastest method is chosen;
+#'   `'rectangle'` for flat 2D meshes with no CRS,
+#'   `'sliced-spherical'` for CRS `'longlat'` meshes, and
+#'   `'triangulated'` for all other meshes.
 #' @param R Numerical value only applicable to spherical and geographical meshes. It is interpreted as
-#'   \code{R} is the equivalent Earth radius, in km, used to scale the lambda intensity.
+#'   `R` is the equivalent Earth radius, in km, used to scale the lambda intensity.
 #'     For CRS enabled meshes, the default is 6371. For CRS-less spherical meshes, the default is 1.
 #' @param samplers A `SpatialPolygonsDataFrame` or `inla.mesh` object.
 #'   Simulated points that fall outside these polygons are discarded.
-#' @param ignore.CRS logical; if \code{TRUE}, ignore any CRS information in the mesh. Default \code{FALSE}.
-#'   This affects \code{R} and the permitted values for \code{strategy}.
+#' @param ignore.CRS logical; if `TRUE`, ignore any CRS information in the mesh. Default `FALSE`.
+#'   This affects `R` and the permitted values for `strategy`.
 #'
-#' @return A \code{data.frame} (1D case),
+#' @return A `data.frame` (1D case),
 #'   SpatialPoints (2D flat and 3D spherical surface cases)
 #'   SpatialPointsDataFrame (2D/3D surface cases with multiple samples).
-#'   For multiple samples, the \code{data.frame} output has a
-#'   column \code{'sample'} giving the index for each sample.
+#'   For multiple samples, the `data.frame` output has a
+#'   column `'sample'` giving the index for each sample.
 #' object of point locations.
 #'
 #' @details
 #' \itemize{
 #' \item For crs-less meshes on R2: Lambda is interpreted in the raw coordinate system. Output has an NA CRS.
-#' \item For crs-less meshes on S2: Lambda with raw units, after scaling the mesh to radius \code{R}, if specified.
+#' \item For crs-less meshes on S2: Lambda with raw units, after scaling the mesh to radius `R`, if specified.
 #'   Output is given on the same domain as the mesh, with an NA CRS.
 #' \item For crs meshes on R2: Lambda is interpreted as per km^2, after scaling the globe to the Earth radius 6371 km,
-#'   or \code{R}, if specified. Output given in the same CRS as the mesh.
+#'   or `R`, if specified. Output given in the same CRS as the mesh.
 #' \item For crs meshes on S2: Lambda is interpreted as per km^2, after scaling the globe to the Earth radius 6371 km,
-#'   or \code{R}, if specified. Output given in the same CRS as the mesh.
+#'   or `R`, if specified. Output given in the same CRS as the mesh.
 #' }
 #'
-#' @author Daniel Simpson <\email{dp.simpson@@gmail.com}> (base rectangle and spherical algorithms),
-#' Fabian E. Bachl <\email{bachlfab@@gmail.com}> (inclusion in inlabru, sliced spherical sampling),
-#' Finn Lindgren <\email{finn.lindgren@@gmail.com}> (extended CRS support, triangulated sampling)
+#' @author Daniel Simpson \email{dp.simpson@@gmail.com} (base rectangle and spherical algorithms),
+#' Fabian E. Bachl \email{bachlfab@@gmail.com} (inclusion in inlabru, sliced spherical sampling),
+#' Finn Lindgren \email{finn.lindgren@@gmail.com} (extended CRS support, triangulated sampling)
 #'
 #' @examples
 #' \donttest{
 #' # The INLA package is required
 #' if (require("INLA", quietly = TRUE)) {
-#'
-#' vertices = seq(0, 3, by = 0.1)
-#' mesh = inla.mesh.1d(vertices)
-#' loglambda = 5-0.5*vertices
-#' pts = sample.lgcp(mesh, loglambda)
-#' pts$y = 0
-#' plot(vertices, exp(loglambda), type = "l", ylim = c(0,150))
-#' points(pts, pch = "|" )
-#'
+#'   vertices <- seq(0, 3, by = 0.1)
+#'   mesh <- inla.mesh.1d(vertices)
+#'   loglambda <- 5 - 0.5 * vertices
+#'   pts <- sample.lgcp(mesh, loglambda)
+#'   pts$y <- 0
+#'   plot(vertices, exp(loglambda), type = "l", ylim = c(0, 150))
+#'   points(pts, pch = "|")
 #' }
 #' }
 #'
-#' @examples
 #' \donttest{
 #' # The INLA package is required
 #' if (require("INLA", quietly = TRUE)) {
-#'
-#' data("gorillas", package = "inlabru")
-#' pts = sample.lgcp(gorillas$mesh,
-#'                   loglambda = 1.5,
-#'                   samplers = gorillas$boundary)
-#' ggplot() + gg(gorillas$mesh) + gg(pts)
-#'
+#'   data("gorillas", package = "inlabru")
+#'   pts <- sample.lgcp(gorillas$mesh,
+#'     loglambda = 1.5,
+#'     samplers = gorillas$boundary
+#'   )
+#'   ggplot() +
+#'     gg(gorillas$mesh) +
+#'     gg(pts)
 #' }
 #' }
-
+#'
 sample.lgcp <- function(mesh, loglambda, strategy = NULL, R = NULL, samplers = NULL,
                         ignore.CRS = FALSE) {
   requireINLA()
@@ -159,8 +157,8 @@ sample.lgcp <- function(mesh, loglambda, strategy = NULL, R = NULL, samplers = N
     if (ignore.CRS) {
       mesh$crs <- NULL
     }
-    input.crs <- INLA::inla.CRS(INLA::inla.CRSargs(mesh$crs))
-    input.crs.list <- INLA::inla.as.list.CRSargs(INLA::inla.CRSargs(input.crs))
+    input.crs <- fm_CRS(fm_CRSargs(mesh$crs))
+    input.crs.list <- fm_CRSargs_as_list(fm_CRSargs(input.crs))
     use.crs <- !is.null(input.crs.list$proj) && !ignore.CRS
     is.geocent <- (mesh$manifold == "S2")
 
@@ -184,18 +182,18 @@ sample.lgcp <- function(mesh, loglambda, strategy = NULL, R = NULL, samplers = N
     strategy <- match.arg(strategy, strategies)
 
     if (is.geocent) {
-      space.R <- mean(rowSums(mesh$loc ^ 2) ^ 0.5)
+      space.R <- mean(rowSums(mesh$loc^2)^0.5)
       if (is.null(input.crs.list$units)) {
         space.units <- "m"
       } else {
         space.units <- input.crs.list$units
       }
-      internal.crs <- INLA::inla.CRS("sphere", args = list(a = 1, b = 1, units = "m"))
+      internal.crs <- fm_CRS("sphere", args = list(a = 1, b = 1, units = "m"))
       mesh$loc <- mesh$loc / space.R
       mesh$crs <- internal.crs
     } else {
       if (use.crs) {
-        internal.crs <- INLA::inla.CRS("sphere", args = list(a = 1, b = 1, units = "m"))
+        internal.crs <- fm_CRS("sphere", args = list(a = 1, b = 1, units = "m"))
       } else {
         internal.crs <- CRS(as.character(NA))
         mesh$crs <- NULL
@@ -222,7 +220,7 @@ sample.lgcp <- function(mesh, loglambda, strategy = NULL, R = NULL, samplers = N
         if (is.geocent) {
           area.mesh <- mesh
         } else if (use.crs) {
-          area.mesh <- INLA::inla.spTransform(mesh, CRSobj = internal.crs)
+          area.mesh <- fm_spTransform(mesh, CRSobj = internal.crs)
         } else {
           area.mesh <- mesh
           area.R <- 1
@@ -232,7 +230,7 @@ sample.lgcp <- function(mesh, loglambda, strategy = NULL, R = NULL, samplers = N
           area.mesh$graph$tv,
           fem = 0,
           output = "ta"
-        )$ta * area.R ^ 2
+        )$ta * area.R^2
 
         loglambda_tri <- matrix(loglambda[mesh$graph$tv], nrow(mesh$graph$tv), ncol(mesh$graph$tv))
         loglambda_max <- apply(loglambda_tri, 1, max)
@@ -254,7 +252,7 @@ sample.lgcp <- function(mesh, loglambda, strategy = NULL, R = NULL, samplers = N
             (mesh$loc[mesh$graph$tv[triangle, 3], , drop = FALSE] -
               mesh$loc[mesh$graph$tv[triangle, 1], , drop = FALSE]) * points[, 2]
           if (is.geocent) {
-            points <- points / rowSums(points ^ 2) ^ 0.5
+            points <- points / rowSums(points^2)^0.5
           }
         }
 
@@ -314,7 +312,7 @@ sample.lgcp <- function(mesh, loglambda, strategy = NULL, R = NULL, samplers = N
         }
       } else if (strategy == "spherical") {
         # Simulate number of points
-        area <- 4 * pi * area.R ^ 2
+        area <- 4 * pi * area.R^2
         lambda_max <- max(loglambda)
         Npoints <- rpois(n = 1, lambda = area * exp(lambda_max))
         if (Npoints > 5000000) {
@@ -329,7 +327,7 @@ sample.lgcp <- function(mesh, loglambda, strategy = NULL, R = NULL, samplers = N
           z <- runif(n = Npoints, min = -1, max = 1)
           # Choose t uniformly distributed on [0, 2*pi).
           t <- runif(n = Npoints, min = 0, max = 2 * pi)
-          r <- sqrt(1 - z ^ 2)
+          r <- sqrt(1 - z^2)
           x <- r * cos(t)
           y <- r * sin(t)
 
@@ -358,7 +356,7 @@ sample.lgcp <- function(mesh, loglambda, strategy = NULL, R = NULL, samplers = N
         }
         slat.range <- pmax(-1, pmin(1, sin(lat.range * pi / 180)))
         radlon.range <- lon.range * pi / 180
-        area <- (4 * pi * area.R ^ 2) * lon.rel * lat.rel
+        area <- (4 * pi * area.R^2) * lon.rel * lat.rel
 
         lambda_max <- max(loglambda)
         Npoints <- rpois(n = 1, lambda = area * exp(lambda_max))
@@ -380,7 +378,7 @@ sample.lgcp <- function(mesh, loglambda, strategy = NULL, R = NULL, samplers = N
           z <- runif(n = n.points, min = slat.range[1], max = slat.range[2]) # transforms into latitude
           # Choose t uniformly distributed on [0, 2*pi).
           angle <- runif(n = n.points, min = radlon.range[1], max = radlon.range[2])
-          r <- sqrt(1 - z ^ 2)
+          r <- sqrt(1 - z^2)
           x <- r * cos(angle)
           y <- r * sin(angle)
 
@@ -420,7 +418,7 @@ sample.lgcp <- function(mesh, loglambda, strategy = NULL, R = NULL, samplers = N
 
     if (is.geocent) {
       if (length(ret) > 0) {
-        ret <- sp::spTransform(ret, INLA::inla.CRS("sphere", args = list(a = space.R, b = space.R, units = "m")))
+        ret <- sp::spTransform(ret, fm_CRS("sphere", args = list(a = space.R, b = space.R, units = "m")))
       } else if (multi.samples) {
         ret <- SpatialPointsDataFrame(matrix(0, 1, 3), data = data.frame(sample = 1))[-1]
       } else {
@@ -465,4 +463,4 @@ sample.lgcp <- function(mesh, loglambda, strategy = NULL, R = NULL, samplers = N
   }
 
   ret
-}
\ No newline at end of file
+}
